==> pm2-monitor-0.0.3.tgz: package/scripts/main_scripts.js <==

var globalLogs = [];

client.on('transport:down', function() {

    $('#processlist').html('<tr><td colspan="8"> Conexao Perdida ...</td></tr>');

});
client.on('transport:up', function() {

    connect();


});
function connect(){


    client.subscribe('/updates', function(message) {

        processData(message.Data);

    });

}
function sendCommand(_command)
{

    getData(_command,"flush");


}

$(function () {

    getData(0,"getdata");
    renderGraphsCPU();
    connect();

});

function getData(pm_id,path)
{

    var data = {

        id:pm_id,
        path:path

    }

    client.publish('/getdata',data);

}

function addLogs(_obj,pm_id)
{

    if($(_obj).attr('checked') === undefined)
    {
        globalLogs.push(pm_id);

    }
    else
    {
        globalLogs = $.grep(globalLogs,function(e){return e != pm_id})
    }
    getData(0,"getdata");


}
function renderGraphsMemory(_totalmemory)
{


    $('#totalmemory').highcharts({

        chart: {
            type: 'gauge',
            plotBackgroundColor: null,
            plotBackgroundImage: null,
            plotBorderWidth: 0,
            plotShadow: false
        },

        title: {
            text: ''
        },
        credits:{
            enabled:false

        },

        pane: {
            startAngle: -150,
            endAngle: 150,
            background: [{
                backgroundColor: {
                    linearGradient: { x1: 0, y1: 0, x2: 0, y2: 1 },
                    stops: [
                    [0, '#FFF'],
                    [1, '#333']
                    ]
                },
                borderWidth: 0,
                outerRadius: '109%'
            }, {
                backgroundColor: {
                    linearGradient: { x1: 0, y1: 0, x2: 0, y2: 1 },
                    stops: [
                    [0, '#333'],
                    [1, '#FFF']
                    ]
                },
                borderWidth: 1,
                outerRadius: '107%'
            }, {
                // default background
            }, {
                backgroundColor: '#DDD',
                borderWidth: 0,
                outerRadius: '105%',
                innerRadius: '103%'
            }]
        },
        yAxis: {
            min: 0,
            max: _totalmemory,

            minorTickInterval: 'auto',
            minorTickWidth: 1,
            minorTickLength: 10,
            minorTickPosition: 'inside',
            minorTickColor: '#666',

            tickPixelInterval: 30,
            tickWidth: 2,
            tickPosition: 'inside',
            tickLength: 10,
            tickColor: '#666',
            labels: {
                step: 2,
                rotation: 'auto'
            },
            title: {
                text: ''
            },
            plotBands: [{
                from: 0,
                to: _totalmemory /3,
                color: '#55BF3B' // green
            }, {
                from: _totalmemory/3,
                to: _totalmemory/2,
                color: '#DDDF0D' // yellow
            }, {
                from: _totalmemory/2,
                to: _totalmemory,
                color: '#DF5353' // red
            }]
        },

        series: [{
            name: 'Usage',
            data: [80],
            tooltip: {
                valueSuffix: ' GB'
            }
        }]

    });


}

function renderGraphsCPU(){

   var gaugeOptions = {

    chart: {
        type: 'solidgauge'
    },

    title: null,

    pane: {
        center: ['50%', '85%'],
        size: '140%',
        startAngle: -90,
        endAngle: 90,
        background: {
            backgroundColor: (Highcharts.theme && Highcharts.theme.background2) || '#EEE',
            innerRadius: '60%',
            outerRadius: '100%',
            shape: 'arc'
        }
    },

    tooltip: {
        enabled: false
    },

        // the value axis
        yAxis: {
            stops: [
                [0.1, '#55BF3B'], // green
                [0.5, '#DDDF0D'], // yellow
                [0.9, '#DF5353'] // red
                ],
                lineWidth: 0,
                minorTickInterval: null,
                tickPixelInterval: 400,
                tickWidth: 0,
                title: {
                    y: -70
                },
                labels: {
                    y: 16
                }
            },

            plotOptions: {
                solidgauge: {
                    dataLabels: {
                        y: 5,
                        borderWidth: 0,
                        useHTML: true
                    }
                }
            }
        };


        $('#totalcpu').highcharts(Highcharts.merge(gaugeOptions, {
            yAxis: {
                min: 0,
                max: 100,
                title: {
                    text: ''
                }
            },

            credits: {
                enabled: false
            },

            series: [{
                name: 'Usage',
                data: [0],
                dataLabels: {
                    format: '<div style="text-align:center"><span style="font-size:25px;color:' +
                    ((Highcharts.theme && Highcharts.theme.contrastTextColor) || 'black') + '">{y}</span><br/>' +
                    '<span style="font-size:12px;color:silver">%</span></div>'
                },
                tooltip: {
                    valueSuffix: ' %'
                }
            }]

        }));




    }

    function updateCPU(_percentage){

        var chart = $('#totalcpu').highcharts(),
        newVal,
        point;


        if (chart) {

            point = chart.series[0].points[0];
            newVal = _percentage;
            point.update(newVal);
        }

    }
    function updateMemory(_percentage){

        var chart = $('#totalmemory').highcharts(),
        newVal,
        point;


        if (chart) {

            point = chart.series[0].points[0];
            newVal = _percentage;
            point.update(newVal);
        }

    }
    function processData(data){

        var totalMem =0;
        var totalCPU=0;

        $('#processlist').html('');
        $('#logs').html('');

        for(var item in data)
        {

            totalMem += (data[item].memory);
            
            renderGraphsMemory(data[item].totalmem /(1024*1024*1024));

            totalCPU+=data[item].cpu;

            var html = "<tr>";
            html+="<td style='text-align:center;'>"+data[item].pid+"</td>";
            html+="<td style='text-align:center;'>"+data[item].name+"</td>";
            html+="<td style='text-align:center;'>"+data[item].restart+"</td>";
            html+="<td style='text-align:center;'>"+parseInt((new Date().getTime() - data[item].uptime) /60000)+" min</td>";

            html+="<td style='text-align:center;'>"+data[item].cpu+"</td>";
            html+="<td style='text-align:center;'>"+(data[item].memory /1000000).toFixed(2)+" MB</td>";
            if(data[item].status == "online")
            {
                html+="<td style='color:green;text-align:center;'>"+data[item].status+"</td>";    
                html+="<td style='text-align:center;'>";
                html+= "<i class='glyphicon glyphicon-pause' title='Pause process' style='width:20px;' onclick='getData("+data[item].id+",\"stop\")'></i>"
                
                
            }
            else
            {

                html+="<td style='color:red;text-align:center;'>"+data[item].status+"</td>";
                html+="<td style='text-align:center;'>";
                html+="<i class='glyphicon glyphicon-play'style='width:20px;' title='Start process' onclick='getData("+data[item].id+",\"start\")'></i>"
                
                

            }
            html+="<i class='glyphicon glyphicon-refresh' title='Restart process' onclick='getData("+data[item].id+",\"restart\")'></i>";
            

            if($.grep(globalLogs,function(e){return e == data[item].id}).length >0){



                html+="<input type='checkbox' checked onchange='addLogs(this,"+data[item].id+")' style='margin-left:5px;' />";
                $('#logs').append('Logs for '+data[item].name+"\n");
                $('#logs').append('-----------------------------------------\n');
                $('#logs').append(data[item].log);
                $('#logs').append('-----------------------------------------\n');
                $('#logs').append('-----------------------------------------\n\n');
            }
            else
            {
                html+="<input type='checkbox'  onchange='addLogs(this,"+data[item].id+")' style='margin-left:5px;' />"

            }

            html+="</td>";

            html += "</tr>";

            $('#processlist').append(html);
            
            

        }
        

        updateMemory(Number((totalMem/(1024*1024*1024)).toFixed(2)));
        updateCPU(Number((totalCPU).toFixed(2)));

    }

==> pm2-monitor-0.1.4.tgz: package/scripts/main_scripts.js <==

var globalLogs = [];

client.on('transport:down', function() {

    $('#processlist').html('<tr><td colspan="8"> Conexao Perdida ...</td></tr>');

});
client.on('transport:up', function() {

    connect();


});
function connect(){

 client.subscribe('/graphs', function(message) {

        // processData(message.Data);
        var data = message.Data;


        renderGraphsMemory(data.TotalMem );
        updateMemory(data.Memory );
        updateCPU(data.Cpu);

    });
 client.subscribe('/updates', function(message) {

    processData(message.Data);

});

}
function sendCommand(_command)
{

    getData(_command,"flush");


}

$(function () {

    getData(0,"getdata");
    renderGraphsCPU();
    connect();

});

function getData(pm_id,path)
{

    var data = {

        id:pm_id,
        path:path

    };

    client.publish('/getdata',data);

}

function addLogs(_obj,pm_id)
{

    if($(_obj).attr('checked') === undefined)
    {
        globalLogs.push(pm_id);

    }
    else
    {
        globalLogs = $.grep(globalLogs,function(e){return e != pm_id});
    }
    getData(0,"getdata");


}
function renderGraphsMemory(_totalmemory)
{

    if( $('#totalmemory').highcharts() !== undefined)
        return;

    $('#totalmemory').highcharts({

        chart: {
            type: 'gauge',
            plotBackgroundColor: null,
            plotBackgroundImage: null,
            plotBorderWidth: 0,
            plotShadow: false
        },

        title: {
            text: ''
        },
        credits:{
            enabled:false

        },

        pane: {
            startAngle: -150,
            endAngle: 150,
            background: [{
                backgroundColor: {
                    linearGradient: { x1: 0, y1: 0, x2: 0, y2: 1 },
                    stops: [
                    [0, '#FFF'],
                    [1, '#333']
                    ]
                },
                borderWidth: 0,
                outerRadius: '109%'
            }, {
                backgroundColor: {
                    linearGradient: { x1: 0, y1: 0, x2: 0, y2: 1 },
                    stops: [
                    [0, '#333'],
                    [1, '#FFF']
                    ]
                },
                borderWidth: 1,
                outerRadius: '107%'
            }, {
                // default background
            }, {
                backgroundColor: '#DDD',
                borderWidth: 0,
                outerRadius: '105%',
                innerRadius: '103%'
            }]
        },
        yAxis: {
            min: 0,
            max: _totalmemory,

            minorTickInterval: 'auto',
            minorTickWidth: 1,
            minorTickLength: 10,
            minorTickPosition: 'inside',
            minorTickColor: '#666',

            tickPixelInterval: 30,
            tickWidth: 2,
            tickPosition: 'inside',
            tickLength: 10,
            tickColor: '#666',
            labels: {
                step: 2,
                rotation: 'auto'
            },
            title: {
                text: ''
            },
            plotBands: [{
                from: 0,
                to: _totalmemory /3,
                color: '#55BF3B' // green
            }, {
                from: _totalmemory/3,
                to: _totalmemory*2/3,
                color: '#DDDF0D' // yellow
            }, {
                from: _totalmemory*2/3,
                to: _totalmemory,
                color: '#DF5353' // red
            }]
        },

        series: [{
            name: 'Usage',
            data: [80],
            tooltip: {
                valueSuffix: ' GB'
            }
        }]

    });


}

function renderGraphsCPU(){

   var gaugeOptions = {

    chart: {
        type: 'solidgauge'
    },

    title: null,

    pane: {
        center: ['50%', '85%'],
        size: '140%',
        startAngle: -90,
        endAngle: 90,
        background: {
            backgroundColor: (Highcharts.theme && Highcharts.theme.background2) || '#EEE',
            innerRadius: '60%',
            outerRadius: '100%',
            shape: 'arc'
        }
    },

    tooltip: {
        enabled: false
    },

        // the value axis
        yAxis: {
            stops: [
                [0.1, '#55BF3B'], // green
                [0.5, '#DDDF0D'], // yellow
                [0.9, '#DF5353'] // red
                ],
                lineWidth: 0,
                minorTickInterval: null,
                tickPixelInterval: 400,
                tickWidth: 0,
                title: {
                    y: -70
                },
                labels: {
                    y: 16
                }
            },

            plotOptions: {
                solidgauge: {
                    dataLabels: {
                        y: 5,
                        borderWidth: 0,
                        useHTML: true
                    }
                }
            }
        };


        $('#totalcpu').highcharts(Highcharts.merge(gaugeOptions, {
            yAxis: {
                min: 0,
                max: 100,
                title: {
                    text: ''
                }
            },

            credits: {
                enabled: false
            },

            series: [{
                name: 'Usage',
                data: [0],
                dataLabels: {
                    format: '<div style="text-align:center"><span style="font-size:25px;color:' +
                    ((Highcharts.theme && Highcharts.theme.contrastTextColor) || 'black') + '">{point.y:.2f}</span><br/>' +
                    '<span style="font-size:12px;color:silver">%</span></div>'
                },
                tooltip: {
                    valueSuffix: ' %'
                }
            }]

        }));




    }

    function updateCPU(_percentage){

        var chart = $('#totalcpu').highcharts(),
        newVal,
        point;


        if (chart) {

            point = chart.series[0].points[0];
            newVal = _percentage;
            point.update(newVal);
        }

    }
    function updateMemory(_percentage){

        var chart = $('#totalmemory').highcharts(),
        newVal,
        point;


        if (chart) {

            point = chart.series[0].points[0];
            newVal = _percentage;
            point.update(newVal);
        }

    }
    function processData(data){

        var totalMem =0;
        var totalCPU=0;

        var windowPosition = $(window).scrollTop();
        var logPosition = $('pre').scrollTop();

        $('#processlist').html('');
        $('#logs').html('');

        for(var item in data)
        {

            totalMem += (data[item].memory);
            
            

            totalCPU+=data[item].cpu;

            var html = "<tr>";
            html+="<td style='text-align:center;'>"+data[item].pid+"</td>";
            html+="<td style='text-align:center;'>"+data[item].name+"</td>";
            html+="<td style='text-align:center;'>"+data[item].restart+"</td>";
            html+="<td style='text-align:center;'>"+parseInt((new Date().getTime() - data[item].uptime) /60000)+" min</td>";

            html+="<td style='text-align:center;'>"+data[item].cpu+"</td>";
            html+="<td style='text-align:center;'>"+(data[item].memory /1000000).toFixed(2)+" MB</td>";
            if(data[item].status == "online")
            {
                html+="<td style='color:green;text-align:center;'>"+data[item].status+"</td>";    
                html+="<td style='text-align:center;'>";
                html+= "<i class='glyphicon glyphicon-pause' title='Pause process' style='width:20px;' onclick='getData("+data[item].id+",\"stop\")'></i>"
                
                
            }
            else
            {

                html+="<td style='color:red;text-align:center;'>"+data[item].status+"</td>";
                html+="<td style='text-align:center;'>";
                html+="<i class='glyphicon glyphicon-play'style='width:20px;' title='Start process' onclick='getData("+data[item].id+",\"start\")'></i>"
                
                

            }
            html+="<i class='glyphicon glyphicon-refresh' title='Restart process' onclick='getData("+data[item].id+",\"restart\")'></i>";
            

            if($.grep(globalLogs,function(e){return e == data[item].id}).length >0){



                html+="<input type='checkbox' checked onchange='addLogs(this,"+data[item].id+")' style='margin-left:5px;' />";
                $('#logs').append('Logs for '+data[item].name+"\n");
                $('#logs').append('-----------------------------------------\n');
                $('#logs').append(data[item].log);
                $('#logs').append('-----------------------------------------\n');
                $('#logs').append('-----------------------------------------\n\n');
            }
            else
            {
                html+="<input type='checkbox'  onchange='addLogs(this,"+data[item].id+")' style='margin-left:5px;' />"

            }

            html+="</td>";

            html += "</tr>";

            $('#processlist').append(html);
            
            

        }
        
        $(window).scrollTop(windowPosition);
        $('pre').scrollTop(logPosition);

        // updateMemory(Number((totalMem/(1024*1024*1024)).toFixed(2)));
        // updateCPU(Number((totalCPU).toFixed(2)));

    }
